@@ -13,11 +13,11 @@ multi-homed-routing.pl - Policy-based IPv4 routing generator
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -555,7 +555,6 @@ END_OF_FILE
             $cmd_line .= $_;
         }
     }
-    my $rules = "";
     my $values = {
         cmd_line        => $cmd_line,
         interfaces      => $interfaces,
@@ -566,13 +565,11 @@ END_OF_FILE
     };
 
     # Go create a setup-file from the template!
-    $tt->process(\$template, $values, $rules) or
+    my $rules;
+	$tt->process(\$template, $values, \$rules) or
         die sprintf("Template error: %s", $tt->error());
 
-    # To-do: Write the rules to a file.
-    # Print the rules to screen
-    print $rules;
-    return;
+    return $rules;
 }
 
 
@@ -617,11 +614,12 @@ sub main()
                 "interface|i=s@",
                 "routing-table|t=s@",
                 "weight|w=s@",
-                "gateway=s@",
+                "gateway|g=s@",
                 "accept-private-dhcp-addresses!",
-                "add-route=s@",
+                "add-route|r=s@",
                 "policy|p=s",
-                "policy-single-iface=s"
+                "policy-single-iface=s",
+                "output-file|o=s"
     ) or die "Malformed arguments! Stopped.";
 
     pod2usage(-exitval => 0, -verbose => 1) if (defined($opts{help}));
@@ -657,6 +655,7 @@ sub main()
     die "Using this script without two or more routing tables makes no sense! None given." if (!$opts{'routing-table'});
     die "Using this script without two or more routing tables makes no sense!" if (scalar(@{$opts{'routing-table'}}) < 2);
     my @known_policies = (POLICY_EQUAL, POLICY_WEIGHTED, POLICY_SINGLE);
+    $opts{policy} = POLICY_SINGLE if (!$opts{policy} && $opts{'policy-single-iface'});
     die "Unknown --policy given!" if ($opts{policy} && !grep($opts{policy} eq $_, @known_policies));
     die "--policy single needs --policy-single-iface!" if ($opts{policy} eq POLICY_SINGLE && !$opts{'policy-single-iface'});
 
@@ -800,18 +799,18 @@ sub main()
         };
         push(@ifs_to_use, $if_info);
     }
-	
+    
     # Policy given?
     my $policy = POLICY_EQUAL;
     $policy = $opts{policy} if ($opts{policy});
     my $policy_single_interface = $opts{'policy-single-iface'} if ($opts{policy} eq POLICY_SINGLE);
-	my $policy_single_interface_found = 0;
+    my $policy_single_interface_found = 0;
 
     # Crete table cross-references
-	# Confirm, there is a gateway somewhere.
+    # Confirm, there is a gateway somewhere.
     my $apipa_metric = 1002;
     my %networks = ();
-	my $gateway_count = 0;
+    my $gateway_count = 0;
     for my $if_info (@ifs_to_use) {
         # First device to claim a network gets it into the main table.
         $networks{$if_info->{network}} = $if_info->{device} if (!defined($networks{$if_info->{network}}));
@@ -832,22 +831,32 @@ sub main()
             $if_info->{apipa_metric} = $apipa_metric;
             ++$apipa_metric;
         }
-		
-		++$gateway_count if ($if_info->{gateway});
-		$policy_single_interface_found = 1 if ($policy_single_interface && $policy_single_interface eq $if_info->{device});
+        
+        ++$gateway_count if ($if_info->{gateway});
+        $policy_single_interface_found = 1 if ($policy_single_interface && $policy_single_interface eq $if_info->{device});
     }
 
-	# Now that all the facts are there, do some final sanity checks.
-	if (!$gateway_count) {
-		warn "There are no gateways! This routing setup is likely to fail.\n";
-	}
-	if ($policy_single_interface && !$policy_single_interface_found) {
-		die "--policy-single-iface $policy_single_interface is specifying a non-existing interface!";
-	}
+    # Now that all the facts are there, do some final sanity checks.
+    if (!$gateway_count) {
+        warn "There are no gateways! This routing setup is likely to fail.\n";
+    }
+    if ($policy_single_interface && !$policy_single_interface_found) {
+        die "--policy-single-iface $policy_single_interface is specifying a non-existing interface!";
+    }
 
     # Information gathering done!
     # Go figure out the routing
-    routing_rules(\@ifs_to_use, $policy, $policy_single_interface);
+    my $rules = routing_rules(\@ifs_to_use, $policy, $policy_single_interface);
+    if ($opts{"output-file"}) {
+        open(RULES, '>', $opts{"output-file"}) or
+            die sprintf("Cannot open file %s for writing! $!", $opts{"output-file"});
+		print RULES $rules;
+		close(RULES);
+		printf("Wrote rules to %s. Done.\n", $opts{"output-file"});
+    } else {
+        # Output rules to STDOUT
+        print $rules;
+    }
 }
 
 main();
@@ -858,9 +867,8 @@ Jari Turkia, C<< <jatu at hqcodeshop.fi> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-app-dhcpclientutils at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-DHCPClientUtils>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to GitHub https://github.com/HQJaTu/App-DHCPClientUtils.
+I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 
 
